@@ -1,7 +1,7 @@
 """
 Entry point to optimize images e.g:
 
-$ toilmoresdk -a light -i ./my_image.jpg -t 043d6bf8edd1fbf240803c972dd1de0f38b3a4b4 -d ae1ece41e69b839611d5b1956e10a0efa5e0d206.com -p webp0
+$ toilmoresdk -a light -i ./my_image.jpg -t 143d6bf8edd1fbf240803c972dd1de0f38b3a4b5 -d pixellena.com -p webp0
 """
 
 import argparse
@@ -26,6 +26,7 @@ from toilmoresdk.version import __version__
 
 
 def main():
+    print(f'toilmoresdk=={__version__}')
     parser = argparse.ArgumentParser()
 
     parser.add_argument(
@@ -161,10 +162,8 @@ def main():
     if r.status == OptimizationResponseStatus.FAILURE:
         rejection_notice = r.rejection_notice
         print(
-            'rejection_notice: {}, inner_error: {}'.format(
-                rejection_notice.rejection_notice,
-                rejection_notice.inner_error
-            )
+            f'rejection_notice: {rejection_notice.rejection_notice}, '
+            f'inner_error: {rejection_notice.inner_error}'
         )
     elif r.status == OptimizationResponseStatus.SUCCESS:
         output_dir = os.path.dirname(
@@ -178,7 +177,7 @@ def main():
                 precursor
             )
         )
-        print('Optimized image stored at: ', output_dir)
+        print(f'Optimized image stored at: {output_dir}')
 
 
 if __name__ == '__main__':
